#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   pcre-light
version:                0.4.1.3
visibility:             public
id:                     pcre-light-0.4.1.3-6AUpRhigcgYLJWVLm05aZi
key:                    pcre-light-0.4.1.3-6AUpRhigcgYLJWVLm05aZi
license:                BSD-3-Clause
copyright:              (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer:             Daniel Casanueva <coding `at` danielcasanueva.eu>
author:                 Don Stewart
homepage:               https://gitlab.com/daniel-casanueva/haskell/pcre-light
synopsis:
    Portable regex library for Perl 5 compatible regular expressions

description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions.

    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.

    If installation fails with missing pcre/pkg-config, try installing
    the @libpcre3-dev@ package (linux) or running @brew install pcre pkg-config@ (macOS).

category:               Text
abi:                    8150a1bcd1dd7766ba18fb588d5ada3b
exposed:                True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Base
    Text.Regex.PCRE.Light.Char8

import-dirs:            /usr/lib/ghc-9.6.6/site-local/pcre-light-0.4.1.3
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/pcre-light-0.4.1.3 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/pcre-light-0.4.1.3 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-pcre-light
hs-libraries:           HSpcre-light-0.4.1.3-6AUpRhigcgYLJWVLm05aZi
extra-libraries:        pcre
extra-libraries-static: pcre
include-dirs:           /usr/include
depends:                base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html:           /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

